# Example 2.20 of Mehttalo, L. and Lappi, J. 2020. Biometry for forestry and environmental data: With examples in R. CRC Press, 
# 
# Author: Lauri Mehttalo
###############################################################################

windows(width=5,height=7)
par(mfrow=c(4,2),mai=c(0.4,0.5,0.3,0.1),mgp=c(1.7,0.7,0))

# Bivariate normal distribution
install.packages("mnormt")
library(mnormt)

x1A<-seq(3,27,0.4)
x2A<-seq(0,40,0.4)

# x2 comes to x-axis , x1 to y-axis

# Generate a regular grid of points at which the density will be evaluated 
x1<-rep(x1A,each=length(x2A))
x2<-rep(x2A,length(x1A))

xymat<-cbind(x1,x2)   
mu<-c(15,20)
Sigma1<-matrix(c(5^2,0,0,5^2),ncol=2)
Sigma2<-matrix(c(3^2,0,0,5^2),ncol=2)
Sigma3<-matrix(c(3^2,4^2,4^2,7^2),ncol=2)
Sigma4<-matrix(c(3^2,-4^2,-4^2,7^2),ncol=2)

f1<-matrix(dmnorm(xymat, mean = mu, varcov=Sigma1),ncol=length(x1A),byrow=FALSE)
f2<-matrix(dmnorm(xymat, mean = mu, varcov=Sigma2),ncol=length(x1A),byrow=FALSE) 
f3<-matrix(dmnorm(xymat, mean = mu, varcov=Sigma3),ncol=length(x1A),byrow=FALSE) 
f4<-matrix(dmnorm(xymat, mean = mu, varcov=Sigma4),ncol=length(x1A),byrow=FALSE) 

image(x=x2A,y=x1A,f1,col=gray(seq(1,0.2,length=100)),
      main="Joint distribution 1",xlab=expression(x[2]),ylab=expression(x[1]),useRaster=TRUE)
contour(x=x2A,y=x1A,f1,add=TRUE,nlevels=5)
image(x=x2A,y=x1A,f2,col=gray(seq(1,0.2,length=100)),
		main="Joint distribution 2",xlab=expression(x[2]),ylab=expression(x[1]),useRaster=TRUE)
contour(x=x2A,y=x1A,f2,add=TRUE,nlevels=5)
image(x=x2A,y=x1A,f3,col=gray(seq(1,0.2,length=100)),
		main="Joint distribution 3",xlab=expression(x[2]),ylab=expression(x[1]),useRaster=TRUE)
contour(x=x2A,y=x1A,f3,add=TRUE,nlevels=5)
image(x=x2A,y=x1A,f4,col=gray(seq(1,0.2,length=100)),
		main="Joint distribution 4",xlab=expression(x[2]),ylab=expression(x[1]),useRaster=TRUE)
contour(x=x2A,y=x1A,f4,add=TRUE,nlevels=5)
abline(15-4^2/7^2*(-20),-(4/7)^2)

abline(h=20)
abline(h=15.2)
abline(h=10)

abline(v=20)
abline(v=30)
abline(v=10)

xymat<-data.frame(xymat)

x1<-seq(0,30,0.1)
mu<-c(15,20)
Sigma<-matrix(c(3^2,-4^2,-4^2,7^2),ncol=2)

# Using the general formula for conditional density
plot(x1,dmnorm(cbind(x1,20),mu,Sigma)/dnorm(20,mean=mu[2],sd=sqrt(Sigma[2,2])),
     xlab=expression(x[1]),ylab=expression(f*(x[1]*"|"*x[2])),type="l",
     main=expression("Conditional pdf's of "*X[1]),lwd=3)
lines(x1,dmnorm(cbind(x1,10),mu,Sigma)/dnorm(10,mean=mu[2],sd=sqrt(Sigma[2,2])),lwd=3)
lines(x1,dmnorm(cbind(x1,30),mu,Sigma)/dnorm(30,mean=mu[2],sd=sqrt(Sigma[2,2])),lwd=3)

# Using the result on univariate normality of the conditional distribution
for (i in c(10,20,30)){
     lines(x1,dnorm(x1,mean=mu[1]+Sigma[1,2]/Sigma[2,2]*mu[2]-Sigma[1,2]/Sigma[2,2]*i,
     sd=sqrt((1-(Sigma[1,2]/sqrt(Sigma[1,1]*Sigma[2,2]))^2)*Sigma[1,1])),
     lty="dashed",lwd=1,col="white")
     }
	
x2<-seq(0,40,0.1)
plot(x2,dmnorm(cbind(15,x2),mu,Sigma)/dnorm(15,mean=mu[1],sd=sqrt(Sigma[1,1])),
     xlab=expression(x[2]),ylab=expression(f*(x[2]*"|"*x[1])),type="l",
     main=expression("Conditional pdf's of "*X[2]),lwd=3)
lines(x2,dmnorm(cbind(10,x2),mu,Sigma)/dnorm(10,mean=mu[1],sd=sqrt(Sigma[1,1])),lwd=3)
lines(x2,dmnorm(cbind(20,x2),mu,Sigma)/dnorm(20,mean=mu[1],sd=sqrt(Sigma[1,1])),lwd=3)

# Using the result on univariate normality of the conditional distribution
for (i in c(10,15,20)){
     lines(x2,dnorm(x2,mean=mu[2]+Sigma[1,2]/Sigma[1,1]*mu[1]-Sigma[1,2]/Sigma[1,1]*i,
     sd=sqrt((1-(Sigma[1,2]/sqrt(Sigma[2,2]*Sigma[1,1]))^2)*Sigma[2,2])),
     lty="dashed",lwd=1, col="white")
     }

f3fun<-function(x1,x2){
       x<-cbind(x1,x2)
       dmnorm(x,mean=mu,varcov=Sigma)
       }

# Marginal pdf of x1 and x2
# By integrating x2 and x1 numerically out from the joint density
margx1<-function(x1) integrate(function(x2) f3fun(x1,x2),0,100)$value
marg1<-sapply(x1, margx1)
plot(x1,marg1,type="l",main=expression("Marginal pdf of "*X[1]),
     xlab=expression(x[1]),ylab=expression(f(x[1])),lwd=3)

# By using the knowledge of marginal normality
lines(x1,dnorm(x1,mean=mu[1],sd=sqrt(Sigma[1,1])),lty="dashed",lwd=1, col="white")

margx2<-function(x2) integrate(function(x1) f3fun(x1,x2),0,100)$value
marg2<-sapply(x2, margx2)
plot(x2,marg2,type="l",main=expression("Marginal pdf of "*X[2]),
     xlab=expression(x[2]),ylab=expression(f(x[2])),lwd=3)
lines(x2,dnorm(x2,mean=mu[2],sd=sqrt(Sigma[2,2])),lty="dashed",lwd=1, col="white")

