# Example 2.6 of Mehttalo, L. and Lappi, J. 2020. Biometry for forestry and environmental data: With examples in R. CRC Press, 
# 
# Author: Lauri Mehttalo
###############################################################################

# Ellipsoidial tree crown
radius.ellipse<-function(x,b,x0=0,y0=0,h) {
	x<-x
	a<-sqrt(b^2*(1-x0)^2/(b^2-y0^2))
	r<-rep(h*(y0+b),length(x))
	r[x>x0*h&x<=h]<-h*(y0+b*sqrt(1-(x[x>x0*h&x<=h]/h-x0)^2/a^2))
	r[x>h]<-0
	r
}

# cdf of laser observations     
cdf.laser<-function(x,b,x0,y0,h) {
	a<-sqrt(b^2*(1-x0)^2/(b^2-y0^2))
	value<-rep(0,length(x))
	value[x>=x0*h&x<h]<-1-(y0^2+2*y0*b*sqrt(1-(x[x>=x0*h&x<h]/h-x0)^2/a^2)+
				b^2*(1-(x[x>=x0*h&x<h]/h-x0)^2/a^2))/(y0+b)^2
	value[x>=h]<-1
	value
}

# corresponding density       
pdf.laser<-function(x,b,x0,y0,h) {
	a<-sqrt(b^2*(1-x0)^2/(b^2-y0^2))
	value<-rep(0,length(x))
	value[x>x0*h&x<h]<--1/(y0+b)^2*
			(y0*b*(1-(x[x>x0*h&x<h]/h-x0)^2/a^2)^(-1/2)*(-2/(a^2*h)*(x[x>x0*h&x<h]/h-x0))+
				b^2*(-2/(a^2*h)*(x[x>x0*h&x<h]/h-x0)))
	value
}
x0<-0.2
y0<--0.1
b<-0.25
h<-20
x<-seq(0,22,0.01)
r<-radius.ellipse(x,b,x0,y0,h)
windows(width=6,height=5)
par(mfcol=c(2,2),mai=c(0.6,0.5,0.1,0.1),mgp=c(2,0.7,0),cex=0.8)
plot(x,r,xlab="Height, m",ylab="Crown radius, m",ylim=h*c(-0.1,0.15),type="l")
points(h*x0,h*y0)
text(h*x0,h*y0,expression((hx[0]*paste(",")*hy[0])),pos=4)
lines(h*rep(x0,2),h*c(y0,y0+b),lty="dashed")
points(h*rep(x0,2),h*c(y0,y0+b),pch="--")
text(h*x0,h*(y0+b/2),"hb",pos=4)
lines(c(0,h),c(0,0),lty="dashed")
points(c(0,h),c(0,0),pch="I")
text(h/2,0,"h",pos=3)

plot(x,cdf.laser(x,b,x0,y0,h),type="l",xlab="Height, m",ylab="cdf")

plot(x,pdf.laser(x,b,x0,y0,h),type="l",xlab="Height, m",ylab="pdf")

plot(x,pdf.laser(x,b,x0,0,h),type="l",xlab="Height, m",ylab="pdf")
