# Example 2.8 of Mehttalo, L. and Lappi, J. 2020. Biometry for forestry and environmental data: With examples in R. CRC Press, 
# 
# Author: Lauri Mehttalo
###############################################################################

windows(width=5,height=7)
par(mfcol=c(4,2),mai=c(0.4,0.5,0.3,0.1),mgp=c(1.7,0.7,0))

x<-seq(0,25,0.10)
a<-8
b<-0.2
alpha<-5
beta<-15
Fx<-pweibull(x,alpha,beta) 
fx<-dweibull(x,alpha,beta)

# Plot the cdf and density of diameter distribution
plot(x,Fx,xlab="x",ylab=expression(F[X](x)),type="l",main="cdf of diameter")
plot(x,fx,xlab="x",ylab=expression(f[X](x)),type="l",main="pdf of diameter")

# Define the power function
powerf<-function(x,a,b){
        a*x^b
        }
# The inverse of power function
power.inv<-function(y,a,b){
           (y/a)^(1/b)
           }
# The 1st derivative of the inverse power function
dpower.inv<-function(y,a,b){
            1/(a*b)*(y/a)^(1/b-1)
            }

# Plot the HD-curve
plot(x,powerf(x,a,b),xlab="x",ylab="g(x)",type="l",main="HD-curve")
y<-seq(8,17,0.1)
Fy<-pweibull(y,alpha/b,a*beta^b)
fy<-dweibull(y,alpha/b,a*beta^b)

# Plot the cdf and density of height distribution
plot(y,Fy,xlab="y, m",ylab=expression(F[Y](y)),type="l",main="cdf of Y")
plot(y,fy,xlab="y, m",ylab=expression(f[Y](y)),type="l",main="pdf of Y")

# Compute the cdf in another way without computations with pen and paper
Fy2<-pweibull(power.inv(y,a,b),alpha,beta)
fy2<-dweibull(power.inv(y,a,b),alpha,beta)*dpower.inv(y,a,b)

# Check graphically that the two ways gave the same result
plot(y,Fy2,xlab="y, m",ylab=expression(F[Y](y)),type="l",main="cdf2 of Y")
plot(y,fy2,xlab="y, m",ylab=expression(f[Y](y)),type="l",main="pdf2 of Y")
plot(Fy,Fy2,main=expression(F[X]*({g^-1}(y))*" vs "*F[Y](y)))
abline(0,1)
